@@ -1,30 +1,33 @@
 package Resque;
 {
-  $Resque::VERSION = '0.05';
+  $Resque::VERSION = '0.06';
 }
 use Any::Moose;
 use Any::Moose '::Util::TypeConstraints';
 
 # ABSTRACT: Redis-backed library for creating background jobs, placing them on multiple queues, and processing them later.
 
-use Redis;
+use RedisDB;
 use Resque::Job;
 use Resque::Worker;
 use Resque::Failures;
 
 
 subtype 'Sugar::Redis' 
-    => as class_type('Redis');
+    => as class_type('RedisDB');
 coerce 'Sugar::Redis' 
     => from 'Str' 
-    => via { Redis->new( server => $_ ) };
+    => via { 
+        my ( $host, $port ) = split /:/;
+        RedisDB->new( host => $host, port => $port ) 
+    };
 
 has redis => (
     is      => 'ro',
     lazy    => 1,
     coerce  => 1,
     isa     => 'Sugar::Redis',
-    default => sub { Redis->new }
+    default => sub { RedisDB->new }
 );
 
 has namespace => ( is => 'rw', default => sub { 'resque' } );
@@ -78,8 +81,8 @@ sub peek {
 
 sub queues {
     my $self = shift;
-    my @queues = $self->redis->smembers( $self->key('queues') );
-    return wantarray ? @queues : \@queues;
+    my $queues = $self->redis->smembers( $self->key('queues') );
+    return wantarray ? @$queues : $queues;
 }
 
 sub remove_queue {
@@ -101,7 +104,7 @@ sub mass_dequeue {
         $removed += $self->redis->lrem( $queue, 0, $self->new_job($target)->encode );
     }
     else {
-        for my $item ( $self->redis->lrange( $queue, 0, -1 ) ) {
+        for my $item ( @{ $self->redis->lrange( $queue, 0, -1 ) } ) {
             if ( $self->new_job( $item )->class eq $target->{class} ) {
                 $removed += $self->redis->lrem( $queue, 0, $item );
             }
@@ -130,8 +133,8 @@ sub key {
 
 sub keys {
     my $self = shift;
-    my @keys = $self->redis->keys( $self->key('*') );
-    return wantarray ? @keys : \@keys;
+    my $keys = $self->redis->keys( $self->key('*') );
+    return wantarray ? @$keys : $keys;
 }
 
 sub flush_namespace {
@@ -145,8 +148,8 @@ sub flush_namespace {
 sub list_range {
     my ( $self, $key, $start, $count ) = @_;
     my $stop = $count > 0 ? $start + $count - 1 : $count;
-    my @items =  $self->redis->lrange( $key, $start, $stop );
-    return \@items;
+    my $items = $self->redis->lrange( $key, $start, $stop );
+    return $items;
 }
 
 # Used internally to keep track of which queues we've created.
@@ -168,11 +171,11 @@ Resque - Redis-backed library for creating background jobs, placing them on mult
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
-First you create a Resque instance where you configure the L<Redis> backend and then you can
+First you create a Resque instance where you configure the L<RedisDB> backend and then you can
 start sending jobs to be done by workers:
 
     use Resque;
@@ -234,7 +237,7 @@ A lot more about Resque can be read on the original blog post: L<http://github.c
 =head2 redis
 
 Redis instance for this Resque instance.
-Accept a Redis object or string. When a string is
+Accept a L<RedisDB> object or string. When a string is
 passed in, it will be used as Redis server argument.
 
 =head2 namespace
